@@ -1,5 +1,5 @@
-pasteCols<-function(x) {
+pasteCols<-function(x,sep="") {
  pastestring<-paste("list(",paste("x","[",1:dim(x)[1],",]",
   sep="",collapse=","),")",sep="")
- return(do.call(paste,c(eval(parse(text = pastestring)),sep="")))
+ return(do.call(paste,c(eval(parse(text = pastestring)),sep=sep)))
 }
